@@ -78,6 +78,11 @@ BayonneDriver::~BayonneDriver()
 	}
 }
 
+unsigned BayonneDriver::getRegistration(regauth_t *data, unsigned count)
+{
+	return 0;
+}
+
 const char *BayonneDriver::remapDriver(const char *id)
 {
 #ifndef	WIN32
