@@ -365,6 +365,13 @@ const char *BayonneSession::getExternal(const char *id)
 			return var_callid;
 		else if(!stricmp(id, "timeslot"))
 			return var_timeslot;
+		else if(!stricmp(id, "servertype"))
+		{
+			if(Bayonne::provision_gateway)
+				return "gw";
+			else
+				return "as";
+		}
 		else if(!stricmp(id, "deviceid"))
 			return logname;
 		else if(!stricmp(id, "voice"))
