@@ -1332,6 +1332,21 @@ bool BayonneSession::stateXfer(Event *event)
 
 	switch(event->id)
 	{
+	case DIAL_BUSY:
+		if(!scriptEvent("transfer:busy"))
+			error("transfer-busy");
+		setRunning();
+		return true;
+	case DIAL_INVALID:
+		if(!scriptEvent("transfer:invalid"))
+			error("transfer-invalid");
+		setRunning();
+		return true;
+	case DIAL_FAILED:
+		if(!scriptEvent("transfer:failed"))
+			error("transfer-failed");
+		setRunning();
+		return true;
 	case ENTER_STATE:
 		event->errmsg = "feature-unsupported";
 	case ERROR_STATE:
