@@ -65,6 +65,13 @@ static Keydata::Define driver[] = {
 
 Driver Driver::sip;
 
+void Registry::add(ScriptImage *img)
+{
+	Registry *first = (Registry *)img->getPointer("_sip_registry_");
+	next = first;
+	img->setPointer("_sip_registry_", this);
+}
+
 bool Registry::isActive(void)
 {
 	if(!proxy)
@@ -220,6 +227,36 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	server->setValue("uri.conf", CONFIG_FILES "/uri.conf");
 }
 
+unsigned Driver::getRegistration(regauth_t *data, unsigned count)
+{
+	unsigned idx = 0;
+	ScriptImage *img = useImage();
+	Registry *reg = (Registry *)img->getPointer("_sip_registry_");
+
+	while(idx < count && reg)
+	{
+		if(!strnicmp(reg->proxy, "sip:", 4))
+			data[idx].remote = reg->proxy + 4;
+		else
+			data[idx].remote = reg->proxy;
+		data[idx].userid = reg->userid;
+		data[idx].type = reg->type;
+		if(!reg->proxy || !reg->userid)
+			data[idx].status = "invalid";
+		else if(!reg->active)
+			data[idx].status = "failed";
+		else if(reg->getTimer() > 0)
+			data[idx].status = "active";
+		else
+			data[idx].status = "expired";
+		++idx;
+		reg = reg->next;
+	}
+
+	endImage(img);
+	return idx;
+}
+
 bool Driver::getAuthentication(Session *s)
 {
 	char buf[256];
@@ -427,6 +464,7 @@ const char *Driver::assignScript(ScriptImage *img, Line *line)
 			break;
 
 		Registry *reg = (Registry *)img->getMemory(sizeof(Registry));
+		reg->add(img);
 		reg->proxy = NULL;
 		reg->active = true;
 		reg->protocol = "sip";
@@ -583,6 +621,8 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	if(!cp)
 		cp = getLast("duration");
 
+	reg->add(img);
+
 	lcp = cp + strlen(cp) - 1;
 	switch(*lcp)
 	{
@@ -1103,6 +1143,7 @@ killit:
 			break;
 
 		case EXOSIP_CALL_REQUESTFAILURE:
+		case EXOSIP_CALL_MESSAGE_REQUESTFAILURE:
 			session = getCall(sevent->cid);
 			if(!session)
 				break;
@@ -1325,6 +1366,7 @@ sip404:
 			{
 				snprintf(cbuf, sizeof(cbuf), "sipreg.%d", reg->regid);
 				session->setConst("session.registry", cbuf);
+				session->setConst("session.uri_server", reg->proxy);
 				session->setConst("session.uri_local", reg->contact);
 			}
 			else
