@@ -109,13 +109,6 @@ BayonneDriver(driver, KEYS, "h323", false)
 	if(cp)
 		ring_timer = atoi(cp);
 
-#ifdef	HAVE_TESTING
-	if(Bayonne::provision_testing)
-	{
-		server->setValue("h323.conf", SOURCE_FILES "/config/h323.conf");
-		return;
-	}
-#endif
 	server->setValue("h323.conf", CONFIG_FILES "/h323.conf");	
 }
 
