@@ -42,6 +42,8 @@ private:
 	void startDriver(BayonneDriver *d, const char *scr, const char *dial, const char *caller, const char *display);
 	void startSelect(const char *scr, const char *dial, const char *caller, const char *display);
 	void help(void);
+	void paths(void);
+	void reg(BayonneDriver *d);
 	void calls(char **list);
 	void allcalls(void);
 	void spans(void);
