@@ -192,6 +192,8 @@ void Session::help(void)
 	*tcp() << "drivers [names..] - display loaded drivers" << endl;
 	*tcp() << "mon state|all timeslots.. - enable state monitoring" << endl;
 	*tcp() << "nomon timeslots.. - disable state monitoring" << endl;
+	*tcp() << "paths - path configuration of server" << endl;
+        *tcp() << "reg [proto] - display protocol registrations" << endl;
 	*tcp() << "reload - reload script configuration" << endl;
 	*tcp() << "shutdown - shutdown server" << endl;
 	*tcp() << "spans - list active spans in server" << endl;
@@ -201,6 +203,32 @@ void Session::help(void)
 	*tcp() << "uptime - show current server uptime" << endl;
 }
 
+void Session::paths(void)
+{
+	char path[128];
+
+	snprintf(path, sizeof(path),
+		"audio prompts: %s", Bayonne::server->getLast("prompts"));
+	snprintf(path, sizeof(path),
+		"config files:  %s", Script::etc_prefix);
+	*tcp() << path << endl;
+	snprintf(path, sizeof(path), 
+		"data files:    %s", Script::var_prefix);
+	*tcp() << path << endl;
+	snprintf(path, sizeof(path),
+		"log files:     %s", Script::log_prefix);
+	*tcp() << path << endl;
+	snprintf(path, sizeof(path),
+		"run files:     %s", Bayonne::server->getLast("runfiles"));
+	*tcp() << path << endl;
+	snprintf(path, sizeof(path),
+		"script files:  %s", Bayonne::server->getLast("scripts"));
+	*tcp() << path << endl;
+	snprintf(path, sizeof(path),
+		"script macros: %s", Bayonne::server->getLast("include"));
+	*tcp() << path << endl;
+}
+
 void Session::uptime(void)
 {
 	unsigned long upt = Bayonne::uptime();
@@ -380,7 +408,42 @@ void Session::allcalls(void)
 		*tcp() << "*** no active calls found" << endl;
 }
 
+void Session::reg(BayonneDriver *d)
+{
+	const char *proto;
+	regauth_t *data;
+	unsigned count, idx = 0;
+	char buf[80];
 
+	if(!d)
+	{
+		*tcp() << "*** invalid driver or no protocols" << endl;
+		return;
+	}
+
+	data = new regauth_t[1024];
+	count = d->getRegistration(data, 1024);
+	if(!count)
+	{
+		*tcp() << "*** no active registrations" << endl;
+		return;
+	}
+
+	snprintf(buf, sizeof(buf), "%22s %16s %6s %8s",
+		"remote", "userid", "type", "status");
+	*tcp() << buf << endl;
+	while(idx < count)
+	{
+		snprintf(buf, sizeof(buf), "%22s %16s %6s %8s",
+			data[idx].remote, data[idx].userid,
+			data[idx].type, data[idx].status);
+		*tcp() << buf << endl;
+		++idx;
+	}
+
+	delete[] data;
+}
+	
 
 void Session::spans(void)
 {
@@ -525,6 +588,13 @@ void Session::run(void)
 					BayonneDriver::list(&argv[1], 120);
 				drivers(&argv[1]);
 			}
+			else if(!stricmp(*argv, "reg"))
+			{
+				if(argv[1])
+					reg(BayonneDriver::get(argv[1]));
+				else
+					reg(BayonneDriver::getProtocol());
+			}		
 			else if(!stricmp(*argv, "start"))
 			{
 				if(!argv[1])
@@ -565,6 +635,8 @@ void Session::run(void)
 				Bayonne::reload();
 			else if(!stricmp(*argv, "help"))
 				help();
+			else if(!stricmp(*argv, "paths"))
+				paths();
 			else if(!stricmp(*argv, "shutdown"))
 			{
 				Service::active = false;
