@@ -99,6 +99,27 @@ static void version(void)
         exit(0);
 }
 
+static void plugins(void)
+{
+	char *tok, *cp, *sp = (char *)keyserver.getLast("plugins");
+	if(sp && !strnicmp(sp, "no", 2))
+		sp = NULL;
+		
+	if(sp && !*sp)
+		sp = NULL;
+		
+	if(sp)
+		cp = strtok_r(sp, " ,;\t", &tok);
+	else
+		cp = NULL;
+
+	while(cp)
+	{
+		Bayonne::loadPlugin(cp);
+		cp = strtok_r(NULL, " ,;:\t", &tok);
+	}	
+}	
+
 static void loading(void)
 {
 	char buffer[256];
@@ -367,6 +388,7 @@ start:
 			cp = "ivrscript1";
 	}
 #endif
+	plugins();
 	runtime.loadBinder(cp);
 	Bayonne::reload();
 	if(!Bayonne::compile_count)
@@ -417,6 +439,7 @@ static void checking(void)
 	if(cp && !stricmp(cp, "default"))
 		cp = "ivrscript1";
 
+	plugins();
 	runtime.loadBinder(cp);
 	Bayonne::reload();
         if(!Bayonne::compile_count)
